@@ -21,6 +21,7 @@ import functools
 import inspect
 import json
 import logging
+import warnings
 from copy import copy
 from io import StringIO, TextIOWrapper
 from json import JSONEncoder
@@ -28,6 +29,7 @@ from typing import Any, Callable, Dict, Iterable, Optional, Set, Tuple, Type, Ty
 from xml.etree import ElementTree
 
 from .formatters import CurrentFormatter
+from .helpers import BaseHelper
 
 logger = logging.getLogger('serializable')
 logger.setLevel(logging.INFO)
@@ -123,8 +125,7 @@ class _SerializableJsonEncoder(JSONEncoder):
                         new_key = CurrentFormatter.formatter.encode(property_name=new_key)
 
                     if prop_info.custom_type:
-                        if inspect.isclass(prop_info.custom_type) and callable(
-                                getattr(prop_info.custom_type, "serialize", None)):
+                        if prop_info.is_helper_type():
                             v = prop_info.custom_type.serialize(v)
                         else:
                             v = prop_info.custom_type(v)
@@ -155,20 +156,34 @@ def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
     ``serializable``.
     """
     logging.debug(f'Rendering JSON to {cls}...')
+    klass = ObjectMetadataLibrary.klass_mappings.get(f'{cls.__module__}.{cls.__qualname__}', None)
     klass_properties = ObjectMetadataLibrary.klass_property_mappings.get(f'{cls.__module__}.{cls.__qualname__}', {})
 
+    if klass is None:
+        warnings.warn(f'{cls.__module__}.{cls.__qualname__} is not a known serializable class')
+        return None
+
     _data = copy(data)
     for k, v in data.items():
         decoded_k = CurrentFormatter.formatter.decode(property_name=k)
+        if decoded_k in klass.ignore_during_deserialization:
+            logger.debug(f'Ignoring {k} when deserializing {cls.__module__}.{cls.__qualname__}')
+            del _data[k]
+            continue
 
+        new_key = None
         if decoded_k not in klass_properties:
             for p, pi in klass_properties.items():
-                if pi.custom_names.get(SerializationType.JSON, None):
-                    del (_data[k])
-                    _data[p] = v
+                if pi.custom_names.get(SerializationType.JSON, None) == decoded_k:
+                    new_key = p
         else:
-            del (_data[k])
-            _data[decoded_k] = v
+            new_key = decoded_k
+
+        if new_key is None:
+            raise ValueError(f'Unexpected key {k} in data being serialized to {cls.__module__}.{cls.__qualname__}')
+
+        del (_data[k])
+        _data[new_key] = v
 
     for k, v in _data.items():
         prop_info = klass_properties.get(k, None)
@@ -176,7 +191,10 @@ def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
             raise ValueError(f'No Prop Info for {k} in {cls}')
 
         if prop_info.custom_type:
-            _data[k] = prop_info.custom_type(v)
+            if prop_info.is_helper_type():
+                _data[k] = prop_info.custom_type.deserialize(v)
+            else:
+                _data[k] = prop_info.custom_type(v)
         elif prop_info.is_array():
             items = []
             for j in v:
@@ -216,6 +234,9 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
                 if CurrentFormatter.formatter:
                     new_key = CurrentFormatter.formatter.encode(property_name=new_key)
 
+                if prop_info.custom_type and prop_info.is_helper_type():
+                    v = prop_info.custom_type.serialize(v)
+
                 this_e_attributes.update({new_key: str(v)})
 
     this_e = ElementTree.Element(
@@ -249,7 +270,10 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
                     new_key = CurrentFormatter.formatter.encode(property_name=new_key)
 
                 if prop_info.custom_type:
-                    ElementTree.SubElement(this_e, new_key).text = str(prop_info.custom_type.serialize(v))
+                    if prop_info.is_helper_type():
+                        ElementTree.SubElement(this_e, new_key).text = str(prop_info.custom_type.serialize(v))
+                    else:
+                        ElementTree.SubElement(this_e, new_key).text = str(prop_info.custom_type(v))
                 elif prop_info.is_array() and prop_info.xml_array_config:
                     _array_type, nested_key = prop_info.xml_array_config
                     if _array_type and _array_type == XmlArraySerializationType.NESTED:
@@ -289,6 +313,7 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
 def _from_xml(cls: Type[_T], data: Union[TextIOWrapper, ElementTree.Element],
               default_namespace: Optional[str] = None) -> object:
     logging.debug(f'Rendering XML from {type(data)} to {cls}...')
+    klass = ObjectMetadataLibrary.klass_mappings.get(f'{cls.__module__}.{cls.__qualname__}', None)
     klass_properties = ObjectMetadataLibrary.klass_property_mappings.get(f'{cls.__module__}.{cls.__qualname__}', {})
 
     if isinstance(data, TextIOWrapper):
@@ -307,17 +332,22 @@ def _from_xml(cls: Type[_T], data: Union[TextIOWrapper, ElementTree.Element],
     # Handle attributes on the root element if there are any
     for k, v in data.attrib.items():
         decoded_k = CurrentFormatter.formatter.decode(property_name=k)
+        if decoded_k in klass.ignore_during_deserialization:
+            logger.debug(f'Ignoring {decoded_k} when deserializing {cls.__module__}.{cls.__qualname__}')
+            continue
 
         if decoded_k not in klass_properties:
             for p, pi in klass_properties.items():
-                if pi.custom_names.get(SerializationType.XML, None):
+                if pi.custom_names.get(SerializationType.XML, None) == decoded_k:
                     decoded_k = p
 
         prop_info = klass_properties.get(decoded_k, None)
         if not prop_info:
             raise ValueError(f'{decoded_k} is not a known Property for {cls.__module__}.{cls.__qualname__}')
 
-        if prop_info.is_primitive_type():
+        if prop_info.custom_type and prop_info.is_helper_type():
+            _data[decoded_k] = prop_info.custom_type.deserialize(v)
+        elif prop_info.is_primitive_type():
             _data[decoded_k] = prop_info.concrete_type()(v)
         else:
             raise ValueError(f'Non-primitive types not supported from XML Attributes - see {decoded_k}')
@@ -331,7 +361,12 @@ def _from_xml(cls: Type[_T], data: Union[TextIOWrapper, ElementTree.Element],
     # Handle Sub-Elements
     for child_e in data:
         child_e_tag_name = str(child_e.tag).replace('{' + default_namespace + '}', '')
+
         decoded_k = CurrentFormatter.formatter.decode(property_name=child_e_tag_name)
+        if decoded_k in klass.ignore_during_deserialization:
+            logger.debug(f'Ignoring {decoded_k} when deserializing {cls.__module__}.{cls.__qualname__}')
+            continue
+
         if decoded_k not in klass_properties:
             for p, pi in klass_properties.items():
                 if pi.xml_array_config:
@@ -346,7 +381,10 @@ def _from_xml(cls: Type[_T], data: Union[TextIOWrapper, ElementTree.Element],
             raise ValueError(f'{decoded_k} is not a known Property for {cls.__module__}.{cls.__qualname__}')
 
         if prop_info.custom_type:
-            _data[decoded_k] = prop_info.custom_type(child_e.text)
+            if prop_info.is_helper_type():
+                _data[decoded_k] = prop_info.custom_type.deserialize(child_e.text)
+            else:
+                _data[decoded_k] = prop_info.custom_type(child_e.text)
         elif prop_info.is_array() and prop_info.xml_array_config:
             array_type, nested_name = prop_info.xml_array_config
 
@@ -394,12 +432,14 @@ class ObjectMetadataLibrary:
         """
 
         def __init__(self, *, klass: Any, custom_name: Optional[str] = None,
-                     serialization_types: Optional[Iterable[SerializationType]] = None) -> None:
+                     serialization_types: Optional[Iterable[SerializationType]] = None,
+                     ignore_during_deserialization: Optional[Iterable[str]] = None) -> None:
             self._name = str(klass.__name__)
             self._custom_name = custom_name
             if serialization_types is None:
                 serialization_types = _DEFAULT_SERIALIZATION_TYPES
             self._serialization_types = serialization_types
+            self._ignore_during_deserialization = set(ignore_during_deserialization or {})
 
         @property
         def name(self) -> str:
@@ -413,6 +453,10 @@ class ObjectMetadataLibrary:
         def serialization_types(self) -> Iterable[SerializationType]:
             return self._serialization_types
 
+        @property
+        def ignore_during_deserialization(self) -> Set[str]:
+            return self._ignore_during_deserialization
+
         def __repr__(self) -> str:
             return f'<s.oml.SerializableClass name={self.name}>'
 
@@ -491,6 +535,11 @@ class ObjectMetadataLibrary:
         def is_enum(self) -> bool:
             return issubclass(type(self.concrete_type()), enum.EnumMeta)
 
+        def is_helper_type(self) -> bool:
+            if inspect.isclass(self.custom_type):
+                return issubclass(self.custom_type, BaseHelper)
+            return False
+
         def is_primitive_type(self) -> bool:
             return self.concrete_type() in self._PRIMITIVE_TYPES
 
@@ -510,13 +559,15 @@ class ObjectMetadataLibrary:
 
     @classmethod
     def register_klass(cls, klass: _T, custom_name: Optional[str],
-                       serialization_types: Iterable[SerializationType]) -> _T:
+                       serialization_types: Iterable[SerializationType],
+                       ignore_during_deserialization: Optional[Iterable[str]] = None) -> _T:
         if cls.is_klass_serializable(klass=klass):
             return klass
 
         cls.klass_mappings.update({
             f'{klass.__module__}.{klass.__qualname__}': ObjectMetadataLibrary.SerializableClass(  # type: ignore
-                klass=klass, serialization_types=serialization_types
+                klass=klass, serialization_types=serialization_types,
+                ignore_during_deserialization=ignore_during_deserialization
             )
         })
 
@@ -578,8 +629,9 @@ class ObjectMetadataLibrary:
         cls._klass_property_types.update({qual_name: mapped_type})
 
 
-def serializable_class(cls: Optional[Type[_T]] = None, /, *, name: Optional[str] = None,
-                       serialization_types: Optional[Iterable[SerializationType]] = None
+def serializable_class(cls: Optional[Type[_T]] = None, *, name: Optional[str] = None,
+                       serialization_types: Optional[Iterable[SerializationType]] = None,
+                       ignore_during_deserialization: Optional[Iterable[str]] = None
                        ) -> Union[Callable[[Any], Type[_T]], Type[_T]]:
     """
     Decorator used to tell ``serializable`` that a class is to be included in (de-)serialization.
@@ -587,13 +639,17 @@ def serializable_class(cls: Optional[Type[_T]] = None, /, *, name: Optional[str]
     :param cls: Class
     :param name: Alternative name to use for this Class
     :param serialization_types: Serialization Types that are to be supported for this class.
+    :param ignore_during_deserialization: List of properties/elements to ignore during deserialization
     :return:
     """
     if serialization_types is None:
         serialization_types = _DEFAULT_SERIALIZATION_TYPES
 
     def wrap(kls: Type[_T]) -> Type[_T]:
-        ObjectMetadataLibrary.register_klass(klass=kls, custom_name=name, serialization_types=serialization_types or {})
+        ObjectMetadataLibrary.register_klass(
+            klass=kls, custom_name=name, serialization_types=serialization_types or {},
+            ignore_during_deserialization=ignore_during_deserialization
+        )
         return kls
 
     # See if we're being called as @register_klass or @register_klass().
